@@ -3,20 +3,22 @@ package Padre::Plugin::CPAN;
 use warnings;
 use strict;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
+use base 'Padre::Plugin';
 use Wx ':everything';
 use File::Spec ();
 
-my @menu = (
-    ['Edit Config 2',    \&edit_config],
-    ['Install Module', \&install_module],
-    ['Upgrade All Padre Plugins', \&upgrade_all_plugins ],
-);
+sub padre_interfaces {
+	'Padre::Plugin' => '0.18',
+}
 
-sub menu {
-    my ($self) = @_;
-    return @menu;
+sub menu_plugins_simple {
+	'CPAN' => [
+		'Edit Config',    \&edit_config,
+		'Install Module', \&install_module,
+		'Upgrade All Padre Plugins', \&upgrade_all_plugins,
+	];
 }
 
 sub edit_config {
